<?php

/*
Plugin Name: SiteApps
Plugin URI: http://support.siteapps.com/entries/20245852-wordpress-plugin
Description: Automatically install SiteApps tag and instantly brings you the SiteApps features.
Author: Leandro Lages
Version: 1.0
Requires at least: 2.7
Author URI: http://siteapps.com/
License: GPL2
*/

/*  Copyright 2010  Leandro Lages   (email : leandro@siteapps.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

class SiteAppsDivManipulator extends WP_Widget {
        
   function __construct() {
      $widget_ops = array('description' => 'Creates a div for SiteApps manipulation' );
      parent::__construct('sa_divs', 'SiteApps Div Marker', $widget_ops);
   }
   
   function widget( $args, $instance ) {
      extract($args);
      echo $before_widget;
      echo $before_title . $after_title;
      $div_name = apply_filters('widget_div_name', empty($instance['div_name']) ? '&nbsp;' : $instance['div_name'], $instance, $this->id_base);
      echo '<div id="'.$div_name.'"></div>';
      echo $after_widget;
   }
   
   function update( $new_instance, $old_instance ) {
      $instance = $old_instance;
      $instance['div_name'] = strip_tags($new_instance['div_name']);
      return $instance;
   }
   
   function form( $instance ) {
      $instance = wp_parse_args( (array) $instance, array( 'div_name' => '' ) );
      $div_name = strip_tags($instance['div_name']);
?>
      <p><label for="<?php echo $this->get_field_id('div_name'); ?>"><?php echo 'Div ID:'; ?></label>
      <input class="widefat" id="<?php echo $this->get_field_id('div_name'); ?>" name="<?php echo $this->get_field_name('div_name'); ?>" type="text" value="<?php echo esc_attr($div_name); ?>" /></p>
<?php
        }
}


/*
 * Admin User Interface
 */

class SiteAppsPlugin {
   
   private static $info;
   
   public static function init() {
      SiteAppsPlugin::$info['plugin_path'] = dirname(__FILE__);
      add_action('admin_menu', array('SiteAppsPlugin','menuInsertId'));
      add_action('wp_head', array('SiteAppsPlugin', 'insertTag'), 20);
      add_option('SiteAppsId', array());
      add_filter( 'the_content', array('SiteAppsPlugin', 'insertDivs'), 20);
      register_widget('SiteAppsDivManipulator');
      do_action('widgets_init');
   }
   
   public static function warning($type, $str) {
      echo "<div id='message' class='$type'><p>$str</p></div>";
   }
   
   public static function getTag($id) {
      return '
      <script type="text/javascript">
        //<![CDATA[[
        $SA={s:'.$id.'};
        (function(){
            var sa = document.createElement("script"); sa.type = "text/javascript"; sa.async = true;
            sa.src = ("https:" == document.location.protocol ? "https://sj" : "http://j") + ".siteapps.com/sa.js";
            var t = document.getElementsByTagName("script")[0]; t.parentNode.insertBefore(sa, t);
        })();
        //]]>
      </script>
      ';
   }
   
   public static function insertDivs( $content ) {
       if (is_single()) $content = sprintf('<div id="sa_post"></div>%s<div id="sa_footer"></div>',$content);
       return $content;
   }
   
   public static function insertTag() {
      $options = get_option('SiteAppsId');
      if (isset($options['tag'])) {
         printf("<!-- SiteApps Tag-->%s<!-- SiteApps tag end -->\n", $options['tag']);   
      }
   }
   
   public static function menuInsertId() {
      add_options_page('SiteAppsPlugin','SiteApps','manage_options',__FILE__,array("SiteAppsPlugin","pageInsertId"));
   }
   
   public static function pageInsertId() {
      
      // reset
      if (isset($_POST['reset']) && $_POST['reset'] == 'true') {
         update_option('SiteAppsId', array());
         SiteAppsPlugin::warning('error', 'SiteApps Tag is <strong>OFF</strong>. You must enter your SiteApps Id to activate it.');      

      // update site id   
      } elseif (isset($_POST['sa_id']) && $_POST['sa_id'] > 0) {
         
         if (!current_user_can('manage_options')) {
            SiteAppsPlugin::warning('error', 'You cannot edit the SiteApps options.');
            return;
         }
         
         $options['id'] = (int) $_POST['sa_id'];
         $options['tag'] = SiteAppsPlugin::getTag($options['id']);
         update_option('SiteAppsId', $options);
         
         SiteAppsPlugin::warning('updated', 'SiteApps settings updated, SiteApps Tag is <strong>ON</strong>.');
         
      // wrong site id   
      } elseif (isset($_POST['sa_id']) && $_POST['sa_id'] == 0) {
         SiteAppsPlugin::warning('error', 'Invalid SiteApps ID!');  
      }
      
      // load the view
      $buffer = @file_get_contents(SiteAppsPlugin::$info['plugin_path'] . '/insert_id.tpl');
      if (!$buffer) {
         SiteAppsPlugin::warning('error', 'Error reading SiteAppsPlugin template form.');
         return;
      }
      
      $options = get_option("SiteAppsId");
      $sa_id = (isset($options['id'])) ? $options['id'] : '';
      
      echo str_replace('[%SA_ID%]',$sa_id, $buffer);
      
   }

}

add_filter('init', array('SiteAppsPlugin','init'));